@@ -36,16 +36,6 @@ if ! grep -q "100[0-9]:100[0-9]" /etc/passwd; then
 	addgroup $USER cdrom
 	addgroup $USER video
 	addgroup $USER tty
-	# /home/$USER files from /etc/skel.
-	if [ -d /home/$USER ]; then
-		# Path for user desktop files.
-		for i in /home/$USER/.local/share/applications/*.desktop
-		do
-			sed -i s/"user_name"/"$USER"/g $i
-		done
-	else
-		mkdir -p /home/$USER
-	fi
 	# make user be only read/write by user
 	chmod -R 700 /home/$USER
 	# Slim default user.
